==> blanco.plugin.valueobjectdotnet_0.4.1-src.zip: blancoValueObjectDotNetPlugin/src/blanco/plugin/valueobjectdotnet/actions/BlancoValueObjectDotNetGenerateAction.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.valueobjectdotnet.actions;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;

import javax.xml.transform.TransformerException;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PlatformUI;

import blanco.doclisting.BlancoDocListingXml2CombinedXmlValueObject;
import blanco.plugin.valueobjectdotnet.BlancoValueObjectDotNetPlugin;
import blanco.plugin.valueobjectdotnet.editors.BlancoValueObjectDotNetEditor;
import blanco.plugin.valueobjectdotnet.editors.BlancoValueObjectDotNetPluginUtil;
import blanco.valueobject.BlancoValueObjectDotNetMeta2Xml;
import blanco.valueobject.BlancoValueObjectDotNetXml2CsClass;

/**
 * ANV̏łB
 * 
 * TODO ʉFۉNX̎ĂB
 * 
 * @author IGA Tosiki
 */
public class BlancoValueObjectDotNetGenerateAction {
    /**
     * blancoValueObject Java\[XR[hs܂B
     * 
     * @param ifile
     *            Ώۂ̃t@CB
     * @param shell
     *            ẽVFB
     * @param workbenchMonitor
     *            [Nx`j^B
     * @param metaDir
     *            ^fBNgB
     * @param isNameAdjust
     *            Oό`sǂB
     * @throws InvocationTargetException
     *             s̗OB
     * @throws InterruptedException
     *             荞ݗOB
     */
    public final void process(final IFile ifile, final Shell shell,
            IProgressMonitor workbenchMonitor, final String metaDir,
            final boolean isNameAdjust) throws InvocationTargetException,
            InterruptedException {
        if (ifile.getProject().getFolder(metaDir).exists() == false) {
            MessageDialog.openWarning(shell, "\[XR[h", "^fBNg (" + metaDir
                    + ") ݂܂B𒆒f܂B");
            return;
        }

        // Eclipse 3.3 ΍: begin
        // workbenchMonitor𗘗p邱Ƃ~܂B
        // org.eclipse.swt.SWTException: Invalid thread access Ă܂܂B
        // Eclipse 3.3 ΍: end

        try {
            PlatformUI.getWorkbench().getProgressService().busyCursorWhile(
                    new IRunnableWithProgress() {
                        public void run(final IProgressMonitor monitor)
                                throws InvocationTargetException,
                                InterruptedException {
                            try {
                                processInternal(ifile, monitor, metaDir,
                                        isNameAdjust, monitor);
                                return;
                            } catch (Exception e) {
                                // ŏIhqC
                                e.printStackTrace();
                                throw new InvocationTargetException(e, e
                                        .toString());
                            } catch (Error e) {
                                // ŏIhqC
                                e.printStackTrace();
                                throw new InvocationTargetException(e, e
                                        .toString());
                            } finally {
                                // Ō̍Ōł doneƂ܂B
                                monitor.done();
                            }
                        }
                    });
        } catch (InvocationTargetException ex) {
            BlancoValueObjectDotNetPlugin.log(ex);
            // O̒{̌oƂ|CgłB
            MessageDialog.openWarning(shell, "\[XR[h",
                    "O܂B𒆒f܂B\n" + ex.getCause().toString());
            ex.printStackTrace();
        } catch (InterruptedException ex) {
            BlancoValueObjectDotNetPlugin.log(ex);
            MessageDialog.openWarning(shell, "\[XR[h",
                    "荞ݒfO܂B𒆒f܂B\n" + ex.toString());
            ex.printStackTrace();
        } catch (Exception ex) {
            BlancoValueObjectDotNetPlugin.log(ex);
            MessageDialog.openWarning(shell, "\[XR[h",
                    "\ʗO܂B𒆒f܂B\n" + ex.toString());
            ex.printStackTrace();
        } catch (Error er) {
            BlancoValueObjectDotNetPlugin.log(er);
            MessageDialog.openWarning(shell, "\[XR[h",
                    "\ʃG[܂B𒆒f܂B\n" + er.toString());
            er.printStackTrace();
        }
    }

    /**
     * ۂ̃ANVeB
     * 
     * @param ifile
     * @param workbenchMonitor
     * @param metaDir
     * @param isNameAdjust
     * @param monitor
     * @throws CoreException
     * @throws IOException
     * @throws TransformerException
     */
    protected void processInternal(final IFile ifile,
            final IProgressMonitor workbenchMonitor, final String metaDir,
            final boolean isNameAdjust, final IProgressMonitor monitor)
            throws CoreException, IOException, TransformerException {
        monitor.beginTask("blancoValueObjectDotNet\[XR[h", 10);

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask("fBNg: e|tH_̒B");

        // e|tH_U폜܂B
        BlancoValueObjectDotNetPluginUtil.deleteFolder(ifile, workbenchMonitor,
                "tmp/valueobjectdotnet");
        BlancoValueObjectDotNetPluginUtil.createFolder(ifile, workbenchMonitor,
                "tmp/valueobjectdotnet");
        final IFolder tempFolder = BlancoValueObjectDotNetPluginUtil
                .findFolder(ifile, workbenchMonitor, "tmp/valueobjectdotnet");

        // hLgꗗ̂߂̒ԃt@CpfBNgB
        final File blancoTempDirectoryDocListing = ifile.getProject()
                .getFolder("tmp/doclisting").getLocation().toFile();
        blancoTempDirectoryDocListing.mkdirs();

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask(BlancoValueObjectDotNetEditor.BLANCO_META_FILE
                + " (*.xls)܂");
        monitor.worked(1);

        final IFolder findFolder = BlancoValueObjectDotNetPluginUtil
                .findFolder(ifile, workbenchMonitor, metaDir);
        findFolder.refreshLocal(IResource.DEPTH_INFINITE, workbenchMonitor);

        new BlancoValueObjectDotNetMeta2Xml() {
            protected boolean progress(final int progressCurrent,
                    final int progressTotal, final String progressItem) {
                if (monitor.isCanceled()) {
                    // f܂B
                    return false;
                }

                monitor.subTask("^t@C: t@C[" + progressItem + "]܂ ("
                        + progressCurrent + "/" + progressTotal + ")");

                return true;
            }
        }.processDirectory(findFolder.getLocation().toFile(), tempFolder
                .getLocation().toFile().getAbsolutePath());

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask("tH_XV: tmptH_");
        monitor.worked(1);

        tempFolder.refreshLocal(IResource.DEPTH_INFINITE, workbenchMonitor);

        monitor.subTask("tH_쐬: blanco.cstH_");

        IFolder folderTargetDirectory = ifile.getProject().getFolder(
                "blanco.cs");
        if (ifile.getProject().getFolder(metaDir).exists() == false) {
            folderTargetDirectory.create(true, true, workbenchMonitor);
        }

        monitor.subTask("tH_쐬: blanco.cs/maintH_");
        final IFolder folderTargetDirectoryWithMain = folderTargetDirectory
                .getFolder("main");
        if (ifile.getProject().getFolder(metaDir).exists() == false) {
            folderTargetDirectoryWithMain.create(true, true, workbenchMonitor);
        }

        File blancoTargetDirectory = folderTargetDirectory.getLocation()
                .toFile();

        monitor.subTask("Java\[XR[h쐬");
        monitor.worked(1);

        IResource[] resourcesXml2 = tempFolder.members();
        for (int index = 0; index < resourcesXml2.length; index++) {
            if (monitor.isCanceled()) {
                return;
            }
            if (resourcesXml2[index] instanceof IFile) {
                IFile fileLook = (IFile) resourcesXml2[index];
                if (fileLook.getFileExtension().equals("xml") == false) {
                    // gqxmlȊÕt@C̓XLbv܂B
                    continue;
                }

                monitor.subTask("Java\[XR[h쐬: t@C[" + fileLook.getName()
                        + "]܂ (" + (index + 1) + "/"
                        + resourcesXml2.length + ")");

                try {
                    final BlancoValueObjectDotNetXml2CsClass xml2JavaClass = new BlancoValueObjectDotNetXml2CsClass();
                    xml2JavaClass.setNameAdjust(isNameAdjust);
                    xml2JavaClass.process(fileLook.getLocation().toFile(),
                            blancoTargetDirectory);
                } catch (IllegalArgumentException ex) {
                    throw new IllegalArgumentException(

                    "t@C[" + fileLook.getName()
                            + "]̏ɃG[܂B𒆒f܂B\n\n" + ex.toString());
                }
            }
        }

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask("hLgꗗ̂߂̒ԃt@C쐬B");
        monitor.worked(1);

        // hLgꗗ̂߂̒ԃt@C쐬B
        final BlancoDocListingXml2CombinedXmlValueObject doclistingCombine = new BlancoDocListingXml2CombinedXmlValueObject();
        doclistingCombine.process(tempFolder.getLocation().toFile(),
                blancoTempDirectoryDocListing);

        monitor.subTask("tH_XV: blanco.cstH_XV");
        monitor.worked(1);

        if (monitor.isCanceled()) {
            return;
        }

        folderTargetDirectory.refreshLocal(IResource.DEPTH_INFINITE,
                workbenchMonitor);
        return;
    }
}

==> blanco.plugin.valueobjectdotnet_0.5.3-src.zip: blancoValueObjectDotNetPlugin/src/blanco/plugin/valueobjectdotnet/actions/BlancoValueObjectDotNetGenerateAction.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.valueobjectdotnet.actions;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;

import javax.xml.transform.TransformerException;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.operation.IRunnableWithProgress;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.PlatformUI;

import blanco.doclisting.BlancoDocListingXml2CombinedXmlValueObject;
import blanco.plugin.valueobjectdotnet.BlancoValueObjectDotNetPlugin;
import blanco.plugin.valueobjectdotnet.editors.BlancoValueObjectDotNetEditor;
import blanco.plugin.valueobjectdotnet.editors.BlancoValueObjectDotNetPluginUtil;
import blanco.valueobjectdotnet.BlancoValueObjectDotNetMeta2Xml;
import blanco.valueobjectdotnet.BlancoValueObjectDotNetXml2SourceFile;

/**
 * ANV̏łB
 * 
 * TODO ʉFۉNX̎ĂB
 * 
 * @author IGA Tosiki
 */
public class BlancoValueObjectDotNetGenerateAction {
    /**
     * blancoValueObject Java\[XR[hs܂B
     * 
     * @param ifile
     *            Ώۂ̃t@CB
     * @param shell
     *            ẽVFB
     * @param workbenchMonitor
     *            [Nx`j^B
     * @param metaDir
     *            ^fBNgB
     * @param isNameAdjust
     *            Oό`sǂB
     * @throws InvocationTargetException
     *             s̗OB
     * @throws InterruptedException
     *             荞ݗOB
     */
    public final void process(final IFile ifile, final Shell shell,
            IProgressMonitor workbenchMonitor, final String metaDir,
            final boolean isNameAdjust) throws InvocationTargetException,
            InterruptedException {
        if (ifile.getProject().getFolder(metaDir).exists() == false) {
            MessageDialog.openWarning(shell, "\[XR[h", "^fBNg (" + metaDir
                    + ") ݂܂B𒆒f܂B");
            return;
        }

        // Eclipse 3.3 ΍: begin
        // workbenchMonitor𗘗p邱Ƃ~܂B
        // org.eclipse.swt.SWTException: Invalid thread access Ă܂܂B
        // Eclipse 3.3 ΍: end

        try {
            // Eclipse vOC̏̃[ɏ]Ď\[XR[h̕GR[fBOB
            final String encoding = ifile.getProject().getDefaultCharset(true);

            PlatformUI.getWorkbench().getProgressService().busyCursorWhile(
                    new IRunnableWithProgress() {
                        public void run(final IProgressMonitor monitor)
                                throws InvocationTargetException,
                                InterruptedException {
                            try {
                                processInternal(ifile, monitor, metaDir,
                                        isNameAdjust, monitor, encoding);
                                return;
                            } catch (Exception e) {
                                // ŏIhqC
                                e.printStackTrace();
                                throw new InvocationTargetException(e, e
                                        .toString());
                            } catch (Error e) {
                                // ŏIhqC
                                e.printStackTrace();
                                throw new InvocationTargetException(e, e
                                        .toString());
                            } finally {
                                // Ō̍Ōł doneƂ܂B
                                monitor.done();
                            }
                        }
                    });
        } catch (InvocationTargetException ex) {
            BlancoValueObjectDotNetPlugin.log(ex);
            // O̒{̌oƂ|CgłB
            MessageDialog.openWarning(shell, "\[XR[h",
                    "O܂B𒆒f܂B\n" + ex.getCause().toString());
            ex.printStackTrace();
        } catch (InterruptedException ex) {
            BlancoValueObjectDotNetPlugin.log(ex);
            MessageDialog.openWarning(shell, "\[XR[h",
                    "荞ݒfO܂B𒆒f܂B\n" + ex.toString());
            ex.printStackTrace();
        } catch (Exception ex) {
            BlancoValueObjectDotNetPlugin.log(ex);
            MessageDialog.openWarning(shell, "\[XR[h",
                    "\ʗO܂B𒆒f܂B\n" + ex.toString());
            ex.printStackTrace();
        } catch (Error er) {
            BlancoValueObjectDotNetPlugin.log(er);
            MessageDialog.openWarning(shell, "\[XR[h",
                    "\ʃG[܂B𒆒f܂B\n" + er.toString());
            er.printStackTrace();
        }
    }

    /**
     * ۂ̃ANVeB
     * 
     * @param ifile
     * @param workbenchMonitor
     * @param metaDir
     * @param isNameAdjust
     * @param monitor
     * @throws CoreException
     * @throws IOException
     * @throws TransformerException
     */
    protected void processInternal(final IFile ifile,
            final IProgressMonitor workbenchMonitor, final String metaDir,
            final boolean isNameAdjust, final IProgressMonitor monitor,
            final String argEncoding) throws CoreException, IOException,
            TransformerException {
        monitor.beginTask("blancoValueObjectDotNet\[XR[h", 10);

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask("fBNg: e|tH_̒B");

        // e|tH_U폜܂B
        BlancoValueObjectDotNetPluginUtil.deleteFolder(ifile, workbenchMonitor,
                "tmp/valueobjectdotnet");
        BlancoValueObjectDotNetPluginUtil.createFolder(ifile, workbenchMonitor,
                "tmp/valueobjectdotnet");
        final IFolder tempFolder = BlancoValueObjectDotNetPluginUtil
                .findFolder(ifile, workbenchMonitor, "tmp/valueobjectdotnet");

        // hLgꗗ̂߂̒ԃt@CpfBNgB
        final File blancoTempDirectoryDocListing = ifile.getProject()
                .getFolder("tmp/doclisting").getLocation().toFile();
        blancoTempDirectoryDocListing.mkdirs();

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask(BlancoValueObjectDotNetEditor.BLANCO_META_FILE
                + " (*.xls)܂");
        monitor.worked(1);

        final IFolder findFolder = BlancoValueObjectDotNetPluginUtil
                .findFolder(ifile, workbenchMonitor, metaDir);
        findFolder.refreshLocal(IResource.DEPTH_INFINITE, workbenchMonitor);

        new BlancoValueObjectDotNetMeta2Xml() {
            protected boolean progress(final int progressCurrent,
                    final int progressTotal, final String progressItem) {
                if (monitor.isCanceled()) {
                    // f܂B
                    return false;
                }

                monitor.subTask("^t@C: t@C[" + progressItem + "]܂ ("
                        + progressCurrent + "/" + progressTotal + ")");

                return true;
            }
        }.processDirectory(findFolder.getLocation().toFile(), tempFolder
                .getLocation().toFile().getAbsolutePath());

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask("tH_XV: tmptH_");
        monitor.worked(1);

        tempFolder.refreshLocal(IResource.DEPTH_INFINITE, workbenchMonitor);

        monitor.subTask("tH_쐬: blanco.cstH_");

        IFolder folderTargetDirectory = ifile.getProject().getFolder(
                "blanco.cs");
        if (ifile.getProject().getFolder(metaDir).exists() == false) {
            folderTargetDirectory.create(true, true, workbenchMonitor);
        }

        monitor.subTask("tH_쐬: blanco.cs/maintH_");
        final IFolder folderTargetDirectoryWithMain = folderTargetDirectory
                .getFolder("main");
        if (ifile.getProject().getFolder(metaDir).exists() == false) {
            folderTargetDirectoryWithMain.create(true, true, workbenchMonitor);
        }

        File blancoTargetDirectory = folderTargetDirectory.getLocation()
                .toFile();

        monitor.subTask("Java\[XR[h쐬");
        monitor.worked(1);

        IResource[] resourcesXml2 = tempFolder.members();
        for (int index = 0; index < resourcesXml2.length; index++) {
            if (monitor.isCanceled()) {
                return;
            }
            if (resourcesXml2[index] instanceof IFile) {
                IFile fileLook = (IFile) resourcesXml2[index];
                if (fileLook.getFileExtension().equals("xml") == false) {
                    // gqxmlȊÕt@C̓XLbv܂B
                    continue;
                }

                monitor.subTask("Java\[XR[h쐬: t@C[" + fileLook.getName()
                        + "]܂ (" + (index + 1) + "/"
                        + resourcesXml2.length + ")");

                try {
                    final BlancoValueObjectDotNetXml2SourceFile xml2JavaClass = new BlancoValueObjectDotNetXml2SourceFile();
                    xml2JavaClass.setEncoding(argEncoding);
                    xml2JavaClass.setNameAdjust(isNameAdjust);
                    xml2JavaClass.process(fileLook.getLocation().toFile(),
                            blancoTargetDirectory);
                } catch (IllegalArgumentException ex) {
                    throw new IllegalArgumentException(

                    "t@C[" + fileLook.getName()
                            + "]̏ɃG[܂B𒆒f܂B\n\n" + ex.toString());
                }
            }
        }

        if (monitor.isCanceled()) {
            return;
        }

        monitor.subTask("hLgꗗ̂߂̒ԃt@C쐬B");
        monitor.worked(1);

        // hLgꗗ̂߂̒ԃt@C쐬B
        final BlancoDocListingXml2CombinedXmlValueObject doclistingCombine = new BlancoDocListingXml2CombinedXmlValueObject();
        doclistingCombine.process(tempFolder.getLocation().toFile(),
                blancoTempDirectoryDocListing);

        monitor.subTask("tH_XV: blanco.cstH_XV");
        monitor.worked(1);

        if (monitor.isCanceled()) {
            return;
        }

        folderTargetDirectory.refreshLocal(IResource.DEPTH_INFINITE,
                workbenchMonitor);
        return;
    }
}
